Function ets_set_appcpu_boot_addr
pub fn ets_set_appcpu_boot_addr(boot_addr: u32)Expand description
Set App cpu Entry code, code can be called in PRO CPU.
pub fn ets_set_appcpu_boot_addr(boot_addr: u32)Set App cpu Entry code, code can be called in PRO CPU.